@@ -21,6 +21,13 @@ from lib389.dbgen import dbgen
 from lib389.idm.organizationalunit import OrganizationalUnits
 from lib389._constants import DN_DM, PASSWORD, PW_DM
 from lib389.topologies import topology_st
+from lib389.paths import Paths
+from lib389.idm.directorymanager import DirectoryManager
+from lib389.config import LDBMConfig
+
+pytestmark = pytest.mark.tier0
+
+default_paths = Paths()
 
 log = logging.getLogger(__name__)
 
@@ -47,9 +54,10 @@ def import_example_ldif(topology_st):
     ldif = '%s/dirsrv/data/Example.ldif' % topology_st.standalone.get_data_dir()
     import_ldif = topology_st.standalone.get_ldif_dir() + "/Example.ldif"
     shutil.copyfile(ldif, import_ldif)
-    topology_st.standalone.tasks.importLDIF(suffix=DEFAULT_SUFFIX,
-                                            input_file=import_ldif,
-                                            args={TASK_WAIT: True})
+
+    r = ImportTask(topology_st.standalone)
+    r.import_suffix_from_ldif(ldiffile=import_ldif, suffix=DEFAULT_SUFFIX)
+    r.wait()
 
 
 @pytest.fixture(params=ROOTDSE_DEF_ATTR_LIST)
@@ -244,28 +252,34 @@ def test_basic_import_export(topology_st, import_example_ldif):
 
     log.info('Running test_basic_import_export...')
 
-    tmp_dir = '/tmp'
-
     #
     # Test online/offline LDIF imports
     #
     topology_st.standalone.start()
 
     # Generate a test ldif (50k entries)
+    log.info("Generating LDIF...")
     ldif_dir = topology_st.standalone.get_ldif_dir()
     import_ldif = ldif_dir + '/basic_import.ldif'
     dbgen(topology_st.standalone, 50000, import_ldif, DEFAULT_SUFFIX)
 
     # Online
-    try:
-        topology_st.standalone.tasks.importLDIF(suffix=DEFAULT_SUFFIX,
-                                                input_file=import_ldif,
-                                                args={TASK_WAIT: True})
-    except ValueError:
-        log.fatal('test_basic_import_export: Online import failed')
-        assert False
+    log.info("Importing LDIF online...")
+    r = ImportTask(topology_st.standalone)
+    r.import_suffix_from_ldif(ldiffile=import_ldif, suffix=DEFAULT_SUFFIX)
+
+    # Good as place as any to quick test the task has some expected attributes
+    if ds_is_newer('1.4.1.2'):
+        assert r.present('nstaskcreated')
+    assert r.present('nstasklog')
+    assert r.present('nstaskcurrentitem')
+    assert r.present('nstasktotalitems')
+    assert r.present('ttl')
+
+    r.wait()
 
     # Offline
+    log.info("Importing LDIF offline...")
     topology_st.standalone.stop()
     if not topology_st.standalone.ldif2db(DEFAULT_BENAME, None, None, None, import_ldif):
         log.fatal('test_basic_import_export: Offline import failed')
@@ -277,16 +291,15 @@ def test_basic_import_export(topology_st, import_example_ldif):
     #
 
     # Online export
+    log.info("Exporting LDIF online...")
     export_ldif = ldif_dir + '/export.ldif'
-    exportTask = Tasks(topology_st.standalone)
-    try:
-        args = {TASK_WAIT: True}
-        exportTask.exportLDIF(DEFAULT_SUFFIX, None, export_ldif, args)
-    except ValueError:
-        log.fatal('test_basic_import_export: Online export failed')
-        assert False
+
+    r = ExportTask(topology_st.standalone)
+    r.export_suffix_to_ldif(ldiffile=export_ldif, suffix=DEFAULT_SUFFIX)
+    r.wait()
 
     # Offline export
+    log.info("Exporting LDIF offline...")
     topology_st.standalone.stop()
     if not topology_st.standalone.db2ldif(DEFAULT_BENAME, (DEFAULT_SUFFIX,),
                                           None, None, None, export_ldif):
@@ -298,16 +311,14 @@ def test_basic_import_export(topology_st, import_example_ldif):
     #
     # Cleanup - Import the Example LDIF for the other tests in this suite
     #
+    log.info("Restore datrabase, import initial LDIF...")
     ldif = '%s/dirsrv/data/Example.ldif' % topology_st.standalone.get_data_dir()
     import_ldif = topology_st.standalone.get_ldif_dir() + "/Example.ldif"
     shutil.copyfile(ldif, import_ldif)
-    try:
-        topology_st.standalone.tasks.importLDIF(suffix=DEFAULT_SUFFIX,
-                                                input_file=import_ldif,
-                                                args={TASK_WAIT: True})
-    except ValueError:
-        log.fatal('test_basic_import_export: Online import failed')
-        assert False
+
+    r = ImportTask(topology_st.standalone)
+    r.import_suffix_from_ldif(ldiffile=import_ldif, suffix=DEFAULT_SUFFIX)
+    r.wait()
 
     log.info('test_basic_import_export: PASSED')
 
@@ -366,6 +377,7 @@ def test_basic_backup(topology_st, import_example_ldif):
 
     log.info('test_basic_backup: PASSED')
 
+
 def test_basic_db2index(topology_st, import_example_ldif):
     """Assert db2index can operate correctly.
 
@@ -902,7 +914,7 @@ def create_users(topology_st):
 
     log.info('Adding 5 test users')
     for name in user_names:
-        user = users.create(properties={
+        users.create(properties={
             'uid': name,
             'sn': name,
             'cn': name,
@@ -1020,6 +1032,7 @@ def test_connection_buffer_size(topology_st):
         with pytest.raises(ldap.OPERATIONS_ERROR):
             topology_st.standalone.config.replace('nsslapd-connection-buffer', value)
 
+
 @pytest.mark.bz1637439
 def test_critical_msg_on_empty_range_idl(topology_st):
     """Doing a range index lookup should not report a critical message even if IDL is empty
@@ -1092,57 +1105,55 @@ def test_critical_msg_on_empty_range_idl(topology_st):
     # Step 5
     assert not topology_st.standalone.searchErrorsLog('CRIT - list_candidates - NULL idl was recieved from filter_candidates_ext.')
 
-def audit_pattern_found(server, log_pattern):
-    file_obj = open(server.ds_paths.audit_log, "r")
-
-    found = None
-    # Use a while true iteration because 'for line in file: hit a
-    log.info('Audit log contains')
-    while True:
-        line = file_obj.readline()
-        log.info(line)
-        found = log_pattern.search(line)
-        if ((line == '') or (found)):
-            break
-
-    return found
 
+@pytest.mark.bz1647099
 @pytest.mark.ds50026
-def test_ticketldbm_audit(topology_st):
+def test_ldbm_modification_audit_log(topology_st):
     """When updating LDBM config attributes, those attributes/values are not listed
     in the audit log
 
     :id: 5bf75c47-a283-430e-a65c-3c5fd8dbadb8
     :setup: Standalone Instance
     :steps:
-        1. Enable audit log
-        2. Update a set of config attrs in LDBM config
-        3. Disable audit log (to restore the default config)
-        4. Check that config attrs are listed in the audit log
+        1. Bind as DM
+        2. Enable audit log
+        3. Update a set of config attrs in LDBM config
+        4. Restart the server
+        5. Check that config attrs are listed in the audit log
     :expectedresults:
-        1. Should succeeds
-        2. Should succeeds
-        3. Should succeeds
-        4. Should succeeds
+        1. Operation successful
+        2. Operation successful
+        3. Operation successful
+        4. Operation successful
+        5. Audit log should contain modification of attrs"
     """
-    inst = topology_st[0]
 
-    inst.config.enable_log('audit')
+    VALUE = '10001'
+
+    d_manager = DirectoryManager(topology_st.standalone)
+    conn = d_manager.bind()
+    config_ldbm = LDBMConfig(conn)
+
+    log.info("Enable audit logging")
+    conn.config.enable_log('audit')
 
-    #inst.ds_paths.audit_log
     attrs = ['nsslapd-lookthroughlimit', 'nsslapd-pagedidlistscanlimit', 'nsslapd-idlistscanlimit', 'nsslapd-db-locks']
-    mods = []
-    for attr in attrs:
-        mods.append((ldap.MOD_REPLACE, attr, b'10001'))
-    inst.modify_s(DN_CONFIG_LDBM, mods)
-    inst.config.enable_log('audit')
 
     for attr in attrs:
-        log.info("Check %s is replaced in the audit log" % attr)
-        regex = re.compile("^replace: %s" % attr)
-        assert audit_pattern_found(inst, regex)
+        log.info("Set attribute %s to value %s" % (attr, VALUE))
+        config_ldbm.set(attr, VALUE)
+
+    log.info('Restart the server to flush the logs')
+    conn.restart()
+
+    for attr in attrs:
+        log.info("Check if attribute %s is replaced in the audit log" % attr)
+        assert conn.searchAuditLog('replace: %s' % attr)
+        assert conn.searchAuditLog('%s: %s' % (attr, VALUE))
 
 
+@pytest.mark.skipif(not get_user_is_root() or not default_paths.perl_enabled or ds_is_older('1.4.0.0'),
+                    reason="This test is only required if perl is enabled, and requires root.")
 def test_dscreate(request):
     """Test that dscreate works, we need this for now until setup-ds.pl is
     fully discontinued.
@@ -1157,16 +1168,26 @@ def test_dscreate(request):
         2. Should succeeds
     """
 
-    template_file = "dssetup.inf"
+    template_file = "/tmp/dssetup.inf"
     template_text = """[general]
 config_version = 2
+# This invalid hostname ...
 full_machine_name = localhost.localdomain
-
+# Means we absolutely require this.
+strict_host_checking = False
+# In tests, we can be run in containers, NEVER trust
+# that systemd is there, or functional in any capacity
+systemd = False
 
 [slapd]
 instance_name = test_dscreate
 root_dn = cn=directory manager
 root_password = someLongPassword_123
+# We do not have access to high ports in containers,
+# so default to something higher.
+port = 38999
+secure_port = 63699
+
 
 [backend-userroot]
 suffix = dc=example,dc=com
@@ -1175,10 +1196,17 @@ sample_entries = yes
 
     with open(template_file, "w") as template_fd:
         template_fd.write(template_text)
-    cmd = 'dscreate from-file ' + template_file
 
+    # Unset PYTHONPATH to avoid mixing old CLI tools and new lib389
+    tmp_env = os.environ
+    if "PYTHONPATH" in tmp_env:
+        del tmp_env["PYTHONPATH"]
     try:
-        subprocess.check_output(cmd, shell=True, stderr=subprocess.STDOUT)
+        subprocess.check_call([
+            'dscreate',
+            'from-file',
+            template_file
+        ], env=tmp_env)
     except subprocess.CalledProcessError as e:
         log.fatal("dscreate failed!  Error ({}) {}".format(e.returncode, e.output))
         assert False
@@ -1186,7 +1214,7 @@ sample_entries = yes
     def fin():
         os.remove(template_file)
         try:
-            subprocess.check_output('dsctl test_dscreate remove --do-it', shell=True)
+            subprocess.check_call(['dsctl', 'test_dscreate', 'remove', '--do-it'])
         except subprocess.CalledProcessError as e:
             log.fatal("Failed to remove test instance  Error ({}) {}".format(e.returncode, e.output))
 
@@ -1198,5 +1226,3 @@ if __name__ == '__main__':
     # -s for DEBUG mode
     CURRENT_FILE = os.path.realpath(__file__)
     pytest.main("-s %s" % CURRENT_FILE)
-
-
