@@ -17,6 +17,8 @@ from lib389.idm.user import UserAccounts, TEST_USER_PROPERTIES
 from lib389.idm.services import ServiceAccounts
 from lib389.topologies import topology_m2 as topo
 
+pytestmark = pytest.mark.tier1
+
 DEBUGGING = os.getenv("DEBUGGING", default=False)
 if DEBUGGING:
     logging.getLogger(__name__).setLevel(logging.DEBUG)
@@ -126,24 +128,42 @@ def replcheck_cmd_list(topo_tls_ldapi):
 
     ds_replcheck_path = os.path.join(m1.ds_paths.bin_dir, 'ds-replcheck')
 
-    replcheck_cmd = [[ds_replcheck_path, 'online', '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '-l', '1',
-                      '-m', 'ldap://{}:{}'.format(m1.host, m1.port), '--conflicts',
-                      '-r', 'ldap://{}:{}'.format(m2.host, m2.port)],
-                     [ds_replcheck_path, 'online', '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '-l', '1',
-                      '-m', 'ldaps://{}:{}'.format(m1.host, m1.sslport), '--conflicts',
-                      '-r', 'ldaps://{}:{}'.format(m2.host, m2.sslport)],
-                     [ds_replcheck_path, 'online', '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '-l', '1',
-                      '-m', 'ldap://{}:{}'.format(m1.host, m1.port), '-Z', m1.get_ssca_dir(),
-                      '-r', 'ldap://{}:{}'.format(m2.host, m2.port), '--conflicts'],
-                     [ds_replcheck_path, 'online', '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '-l', '1',
-                      '-m', 'ldapi://%2fvar%2frun%2fslapd-{}.socket'.format(m1.serverid), '--conflict',
-                      '-r', 'ldapi://%2fvar%2frun%2fslapd-{}.socket'.format(m2.serverid)],
-                     [ds_replcheck_path, 'offline', '-b', DEFAULT_SUFFIX, '--conflicts', '--rid', '1',
-                      '-m', '/tmp/export_{}.ldif'.format(m1.serverid),
-                      '-r', '/tmp/export_{}.ldif'.format(m2.serverid)]]
+    if ds_is_newer("1.4.1.2"):
+        replcheck_cmd = [[ds_replcheck_path, 'online', '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '-l', '1',
+                          '-m', 'ldap://{}:{}'.format(m1.host, m1.port), '--conflicts',
+                          '-r', 'ldap://{}:{}'.format(m2.host, m2.port)],
+                         [ds_replcheck_path, 'online', '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '-l', '1',
+                          '-m', 'ldaps://{}:{}'.format(m1.host, m1.sslport), '--conflicts',
+                          '-r', 'ldaps://{}:{}'.format(m2.host, m2.sslport)],
+                         [ds_replcheck_path, 'online', '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '-l', '1',
+                          '-m', 'ldap://{}:{}'.format(m1.host, m1.port), '-Z', m1.get_ssca_dir(),
+                          '-r', 'ldap://{}:{}'.format(m2.host, m2.port), '--conflicts'],
+                         [ds_replcheck_path, 'online', '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '-l', '1',
+                          '-m', 'ldapi://%2fvar%2frun%2fslapd-{}.socket'.format(m1.serverid), '--conflict',
+                          '-r', 'ldapi://%2fvar%2frun%2fslapd-{}.socket'.format(m2.serverid)],
+                         [ds_replcheck_path, 'offline', '-b', DEFAULT_SUFFIX, '--conflicts', '--rid', '1',
+                          '-m', '/tmp/export_{}.ldif'.format(m1.serverid),
+                          '-r', '/tmp/export_{}.ldif'.format(m2.serverid)]]
+    else:
+        replcheck_cmd = [[ds_replcheck_path, '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '-l', '1',
+                          '-m', 'ldap://{}:{}'.format(m1.host, m1.port), '--conflicts',
+                          '-r', 'ldap://{}:{}'.format(m2.host, m2.port)],
+                         [ds_replcheck_path, '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '-l', '1',
+                          '-m', 'ldaps://{}:{}'.format(m1.host, m1.sslport), '--conflicts',
+                          '-r', 'ldaps://{}:{}'.format(m2.host, m2.sslport)],
+                         [ds_replcheck_path, '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '-l', '1',
+                          '-m', 'ldap://{}:{}'.format(m1.host, m1.port), '-Z', m1.get_ssca_dir(),
+                          '-r', 'ldap://{}:{}'.format(m2.host, m2.port), '--conflicts'],
+                         [ds_replcheck_path, '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '-l', '1',
+                          '-m', 'ldapi://%2fvar%2frun%2fslapd-{}.socket'.format(m1.serverid), '--conflict',
+                          '-r', 'ldapi://%2fvar%2frun%2fslapd-{}.socket'.format(m2.serverid)],
+                         [ds_replcheck_path, '-b', DEFAULT_SUFFIX, '-D', DN_DM, '-w', PW_DM, '--conflicts',
+                          '-M', '/tmp/export_{}.ldif'.format(m1.serverid),
+                          '-R', '/tmp/export_{}.ldif'.format(m2.serverid)]]
+
     return replcheck_cmd
 
-
+@pytest.mark.skipif(ds_is_older("1.4.1.2"), reason="Not implemented")
 def test_state(topo_tls_ldapi):
     """Check "state" report
 
@@ -341,6 +361,8 @@ def test_inconsistencies(topo_tls_ldapi):
     m2 = topo_tls_ldapi.ms["master2"]
     attr_m1 = "m1_inconsistency"
     attr_m2 = "m2_inconsistency"
+    attr_first = "first ordered valued"
+    attr_second = "second ordered valued"
     attr_m1_only = "123123123"
 
     try:
@@ -353,6 +375,9 @@ def test_inconsistencies(topo_tls_ldapi):
         user_m1.set("description", attr_m1)
         user_m2.set("description", attr_m2)
         user_m1.set("telephonenumber", attr_m1_only)
+        # Add the same multi-valued attrs, but out of order
+        user_m1.set("cn", [attr_first, attr_second])
+        user_m2.set("cn", [attr_second, attr_first])
         time.sleep(2)
 
         for tool_cmd in replcheck_cmd_list(topo_tls_ldapi):
@@ -360,18 +385,85 @@ def test_inconsistencies(topo_tls_ldapi):
             assert attr_m1 in result
             assert attr_m2 in result
             assert attr_m1_only in result
+            if ds_is_newer("1.3.9.1", "1.4.1.2"):
+                assert attr_first not in result
+                assert attr_second not in result
             # Ignore some attributes and check the output
             tool_cmd.extend(['-i', '{},{}'.format('description', 'telephonenumber')])
             result = subprocess.check_output(tool_cmd, encoding='utf-8').lower()
             assert attr_m1 not in result
             assert attr_m2 not in result
             assert attr_m1_only not in result
+            if ds_is_newer("1.3.9.1", "1.4.1.2"):
+                assert attr_first not in result
+                assert attr_second not in result
 
     finally:
         topo_tls_ldapi.resume_all_replicas()
         user_m1.delete()
 
 
+def test_suffix_exists(topo_tls_ldapi):
+    """Check if wrong suffix is provided, server is giving Error: Failed
+    to validate suffix.
+
+    :id: ce75debc-c07f-4e72-8787-8f99cbfaf1e2
+    :setup: Two master replication
+    :steps:
+        1. Run ds-replcheck with wrong suffix (Non Existing)
+    :expectedresults:
+        1. It should be unsuccessful
+    """
+    m1 = topo_tls_ldapi.ms["master1"]
+    m2 = topo_tls_ldapi.ms["master2"]
+    ds_replcheck_path = os.path.join(m1.ds_paths.bin_dir, 'ds-replcheck')
+
+    if ds_is_newer("1.4.1.2"):
+        tool_cmd = [ds_replcheck_path, 'online', '-b', 'dc=test,dc=com', '-D', DN_DM, '-w', PW_DM,
+                    '-m', 'ldaps://{}:{}'.format(m1.host, m1.sslport),
+                    '-r', 'ldaps://{}:{}'.format(m2.host, m2.sslport)]
+    else:
+        tool_cmd = [ds_replcheck_path, '-b', 'dc=test,dc=com', '-D', DN_DM, '-w', PW_DM,
+                    '-m', 'ldaps://{}:{}'.format(m1.host, m1.sslport),
+                    '-r', 'ldaps://{}:{}'.format(m2.host, m2.sslport)]
+
+    result1 = subprocess.Popen(tool_cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, encoding='utf-8')
+    result = result1.communicate()
+    assert "Failed to validate suffix" in result[0]
+
+
+def test_check_missing_tombstones(topo_tls_ldapi):
+    """Check missing tombstone entries is not reported.
+
+    :id: 93067a5a-416e-4243-9418-c4dfcf42e093
+    :setup: Two master replication
+    :steps:
+        1. Pause replication between master and replica
+        2. Add and delete an entry on the master
+        3. Run ds-replcheck
+        4. Verify there are NO complaints about missing entries/tombstones
+    :expectedresults:
+        1. It should be successful
+        2. It should be successful
+        3. It should be successful
+        4. It should be successful
+    """
+    m1 = topo_tls_ldapi.ms["master1"]
+    m2 = topo_tls_ldapi.ms["master2"]
+
+    try:
+        topo_tls_ldapi.pause_all_replicas()
+        users_m1 = UserAccounts(m1, DEFAULT_SUFFIX)
+        user0 = users_m1.create_test_user(1000)
+        user0.delete()
+        for tool_cmd in replcheck_cmd_list(topo_tls_ldapi):
+            result = subprocess.check_output(tool_cmd, encoding='utf-8').lower()
+            assert "entries missing on replica" not in result
+
+    finally:
+        topo_tls_ldapi.resume_all_replicas()
+
+
 if __name__ == '__main__':
     # Run isolated
     # -s for DEBUG mode
