@@ -14,6 +14,8 @@ from lib389.topologies import topology_st
 from lib389._constants import PASSWORD, DEFAULT_SUFFIX, DN_DM, SUFFIX
 from lib389.utils import *
 
+pytestmark = pytest.mark.tier1
+
 logging.getLogger(__name__).setLevel(logging.DEBUG)
 log = logging.getLogger(__name__)
 
@@ -31,7 +33,7 @@ def test_filter_escaped(topology_st):
          1. Add a test user with an '*' in its attribute value
             i.e. 'cn=test * me'
          2. Add another similar test user without '*' in its attribute value
-         3. Search test user using search filter "cn=*\**"
+         3. Search test user using search filter "cn=*\\**"
     :expectedresults:
          1. This should pass
          2. This should pass
@@ -64,9 +66,9 @@ def test_filter_escaped(topology_st):
         assert False
 
     try:
-        entry = topology_st.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE, 'cn=*\**')
+        entry = topology_st.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE, 'cn=*\\**')
         if not entry or len(entry) > 1:
-            log.fatal('test_filter_escaped: Entry was not found using "cn=*\**"')
+            log.fatal('test_filter_escaped: Entry was not found using "cn=*\\**"')
             assert False
     except ldap.LDAPError as e:
         log.fatal('test_filter_escaped: Failed to search for user(%s), error: %s' %
