@@ -10,7 +10,9 @@ from lib389.backend import Backends
 from lib389.properties import TASK_WAIT
 from lib389.utils import time, ldap, os, logging
 from lib389.topologies import topology_st as topo
-from lib389._constants import BACKEND_NAME, BACKEND_SUFFIX
+from lib389.dbgen import dbgen
+
+pytestmark = pytest.mark.tier1
 
 DEBUGGING = os.getenv("DEBUGGING", default=False)
 if DEBUGGING:
@@ -23,6 +25,52 @@ TEST_SUFFIX1 = "dc=importest1,dc=com"
 TEST_BACKEND1 = "importest1"
 TEST_SUFFIX2 = "dc=importest2,dc=com"
 TEST_BACKEND2 = "importest2"
+TEST_DEFAULT_SUFFIX = "dc=default,dc=com"
+TEST_DEFAULT_NAME = "default"
+
+
+def test_import_be_default(topo):
+    """ Create a backend using the name "default". previously this name was
+    used int
+
+    :id: 8e507beb-e917-4330-8cac-1ff0eee10508
+    :feature: Import
+    :setup: Standalone instance
+    :steps:
+        1. Create a test suffix using the be name of "default"
+        2. Create an ldif for the "default" backend
+        3. Import ldif
+        4. Verify all entries were imported
+    :expectedresults:
+        1. Success
+        2. Success
+        3. Success
+        4. Success
+    """
+    log.info('Adding suffix:{} and backend: {}...'.format(TEST_DEFAULT_SUFFIX,
+                                                          TEST_DEFAULT_NAME))
+    backends = Backends(topo.standalone)
+    backends.create(properties={'nsslapd-suffix': TEST_DEFAULT_SUFFIX,
+                                'name': TEST_DEFAULT_NAME})
+
+    log.info('Create LDIF file and import it...')
+    ldif_dir = topo.standalone.get_ldif_dir()
+    ldif_file = os.path.join(ldif_dir, 'default.ldif')
+    dbgen(topo.standalone, 5, ldif_file, TEST_DEFAULT_SUFFIX)
+
+    log.info('Stopping the server and running offline import...')
+    topo.standalone.stop()
+    assert topo.standalone.ldif2db(TEST_DEFAULT_NAME, None, None,
+                                   None, ldif_file)
+    topo.standalone.start()
+
+    log.info('Verifying entry count after import...')
+    entries = topo.standalone.search_s(TEST_DEFAULT_SUFFIX,
+                                       ldap.SCOPE_SUBTREE,
+                                       "(objectclass=*)")
+    assert len(entries) > 1
+
+    log.info('Test PASSED')
 
 
 def test_del_suffix_import(topo):
@@ -41,31 +89,26 @@ def test_del_suffix_import(topo):
 
     log.info('Adding suffix:{} and backend: {}'.format(TEST_SUFFIX1, TEST_BACKEND1))
     backends = Backends(topo.standalone)
-    backend = backends.create(properties={BACKEND_SUFFIX: TEST_SUFFIX1, BACKEND_NAME: TEST_BACKEND1})
+    backend = backends.create(properties={'nsslapd-suffix': TEST_SUFFIX1,
+                                          'name': TEST_BACKEND1})
 
     log.info('Create LDIF file and import it')
     ldif_dir = topo.standalone.get_ldif_dir()
     ldif_file = os.path.join(ldif_dir, 'suffix_del1.ldif')
-    try:
-        topo.standalone.buildLDIF(10, ldif_file, suffix=TEST_SUFFIX1)
-    except OSError as e:
-        log.fatal('Failed to create test ldif, {} - {}'.format(e.errno, e.strerror))
-        assert False
+
+    dbgen(topo.standalone, 10, ldif_file, TEST_SUFFIX1)
 
     log.info('Stopping the server and running offline import')
-    topo.standalone.stop(timeout=10)
+    topo.standalone.stop()
     assert topo.standalone.ldif2db(TEST_BACKEND1, TEST_SUFFIX1, None, None, ldif_file)
-    topo.standalone.start(timeout=5)
+    topo.standalone.start()
 
     log.info('Deleting suffix-{}'.format(TEST_SUFFIX2))
     backend.delete()
 
     log.info('Adding the same database-{} after deleting it'.format(TEST_BACKEND1))
-    try:
-        backends.create(properties={BACKEND_SUFFIX: TEST_SUFFIX1, BACKEND_NAME: TEST_BACKEND1})
-    except ldap.LDAPError as e:
-        log.error('Failed to add backend-{}, error-{}'.format(TEST_SUFFIX1, e.message['desc']))
-        assert False
+    backends.create(properties={'nsslapd-suffix': TEST_SUFFIX1,
+                                'name': TEST_BACKEND1})
 
 
 def test_del_suffix_backend(topo):
@@ -84,35 +127,25 @@ def test_del_suffix_backend(topo):
 
     log.info('Adding suffix:{} and backend: {}'.format(TEST_SUFFIX2, TEST_BACKEND2))
     backends = Backends(topo.standalone)
-    backend = backends.create(properties={BACKEND_SUFFIX: TEST_SUFFIX2, BACKEND_NAME: TEST_BACKEND2})
+    backend = backends.create(properties={'nsslapd-suffix': TEST_SUFFIX2,
+                                           'name': TEST_BACKEND2})
 
     log.info('Create LDIF file and import it')
     ldif_dir = topo.standalone.get_ldif_dir()
     ldif_file = os.path.join(ldif_dir, 'suffix_del2.ldif')
-    try:
-        topo.standalone.buildLDIF(10, ldif_file, suffix=TEST_SUFFIX2)
-    except OSError as e:
-        log.fatal('Failed to create test ldif, {} - {}'.format(e.errno, e.strerror))
-        assert False
 
-    log.info('Running online import with importLDIF task')
-    try:
-        topo.standalone.tasks.importLDIF(suffix=TEST_SUFFIX2, input_file=ldif_file, args={TASK_WAIT: True})
-    except ValueError as e:
-        log.error('Import failed' + e.message('desc'))
-        raise
+    dbgen(topo.standalone, 10, ldif_file, TEST_SUFFIX2)
+
+    topo.standalone.tasks.importLDIF(suffix=TEST_SUFFIX2, input_file=ldif_file, args={TASK_WAIT: True})
 
     log.info('Deleting suffix-{}'.format(TEST_SUFFIX2))
     backend.delete()
 
     log.info('Adding the same database-{} after deleting it'.format(TEST_BACKEND2))
-    try:
-        backends.create(properties={BACKEND_SUFFIX: TEST_SUFFIX2, BACKEND_NAME: TEST_BACKEND2})
-    except ldap.LDAPError as e:
-        log.error('Failed to add backend-{}, error-{}'.format(TEST_SUFFIX1, e.message['desc']))
-        assert False
+    backends.create(properties={'nsslapd-suffix': TEST_SUFFIX2,
+                                'name': TEST_BACKEND2})
     log.info('Checking if server can be restarted after re-adding the same database')
-    topo.standalone.restart(timeout=10)
+    topo.standalone.restart()
     assert not topo.standalone.detectDisorderlyShutdown()
 
 
